@@ -31,6 +31,7 @@ implementations.
 * [Masked Language Model](transformers/mlm/index.html)
 * [MLP-Mixer: An all-MLP Architecture for Vision](transformers/mlp_mixer/index.html)
 * [Pay Attention to MLPs (gMLP)](transformers/gmlp/index.html)
+* [Vision Transformer (ViT)](transformers/vit/index.html)
 
 #### ✨ [Recurrent Highway Networks](recurrent_highway_networks/index.html)
 
@@ -38,6 +39,8 @@ implementations.
 
 #### ✨ [HyperNetworks - HyperLSTM](hypernetworks/hyper_lstm.html)
 
+#### ✨ [ResNet](resnet/index.html)
+
 #### ✨ [Capsule Networks](capsule_networks/index.html)
 
 #### ✨ [Generative Adversarial Networks](gan/index.html)
@@ -50,6 +53,17 @@ implementations.
 
 #### ✨ [Sketch RNN](sketch_rnn/index.html)
 
+#### ✨ Graph Neural Networks
+
+* [Graph Attention Networks (GAT)](graphs/gat/index.html)
+* [Graph Attention Networks v2 (GATv2)](graphs/gatv2/index.html)
+
+#### ✨ [Counterfactual Regret Minimization (CFR)](cfr/index.html)
+
+Solving games with incomplete information such as poker with CFR.
+
+* [Kuhn Poker](cfr/kuhn/index.html)
+
 #### ✨ [Reinforcement Learning](rl/index.html)
 * [Proximal Policy Optimization](rl/ppo/index.html) with
  [Generalized Advantage Estimation](rl/ppo/gae.html)
@@ -74,6 +88,8 @@ implementations.
 * [Weight Standardization](https://nn.labml.ai/normalization/weight_standardization/index.html)
 * [Batch-Channel Normalization](https://nn.labml.ai/normalization/batch_channel_norm/index.html)
 
+#### ✨ [Distillation](distillation/index.html)
+
 ### Installation
 
 ```bash
