@@ -40,7 +40,7 @@ This avoids outputs of nodes from always falling beyond the active range of the
 
 Here is [the training code](experiment.html) for training
 a VGG network that uses weight standardization to classify CIFAR-10 data.
-This uses a [2D-Convolution Layer with Weight Standardization](../conv2d.html).
+This uses a [2D-Convolution Layer with Weight Standardization](conv2d.html).
 
 [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/lab-ml/nn/blob/master/labml_nn/normalization/weight_standardization/experiment.ipynb)
 [![View Run](https://img.shields.io/badge/labml-experiment-brightgreen)](https://app.labml.ai/run/f4a783a2a7df11eb921d0242ac1c0002)
